:mod:`Conversions` --- Fonctions de conversions
===============================================
Le module :mod:`Conversions`


.. automodule:: pyromaths.outils.Conversions
    :members:
    :special-members:
    :undoc-members:
..    :private-members:
      :show-inheritance:
